pub enum MmapBacking {
ReadOnly(Mmap),
ReadWrite(MmapMut),
Owned(Vec<u8>),
}Expand description
Owns the backing memory for a TRX data array.
May be a read-only mmap, a read-write mmap, or an owned heap buffer (used for converted offsets, deep copies, etc.).
Variants
Implementations
Sourceimpl MmapBacking
impl MmapBacking
Sourcepub fn as_bytes_mut(&mut self) -> Result<&mut [u8]>
pub fn as_bytes_mut(&mut self) -> Result<&mut [u8]>
Mutable raw bytes view (only for ReadWrite and Owned).
pub fn is_mapped(&self) -> bool
Sourcepub fn cast_slice<T: Pod>(&self) -> &[T]
pub fn cast_slice<T: Pod>(&self) -> &[T]
Cast the raw bytes to a typed slice.
Panics if the bytes are not aligned or the length is not a multiple
of size_of::<T>().
Sourcepub fn cast_slice_mut<T: Pod>(&mut self) -> Result<&mut [T]>
pub fn cast_slice_mut<T: Pod>(&mut self) -> Result<&mut [T]>
Cast the raw bytes to a mutable typed slice.