pub fn copy_metadata_any_trx(
target: AnyTrxFile,
source: &AnyTrxFile,
opts: &CopyMetadataOptions,
) -> Result<AnyTrxFile>Expand description
Copy metadata from source onto target, returning the modified target.
pub fn copy_metadata_any_trx(
target: AnyTrxFile,
source: &AnyTrxFile,
opts: &CopyMetadataOptions,
) -> Result<AnyTrxFile>Copy metadata from source onto target, returning the modified target.