pub enum AnyTrxFile {
F16(TrxFile<f16>),
F32(TrxFile<f32>),
F64(TrxFile<f64>),
}Expand description
A type-erased TRX container that can hold any position dtype.
Use this when the position dtype is not known at compile time (e.g. CLI tools
that accept arbitrary .trx files).
Variants
Implementations
Sourceimpl AnyTrxFile
impl AnyTrxFile
Sourcepub fn load(path: &Path) -> Result<Self>
pub fn load(path: &Path) -> Result<Self>
Load a TRX file, detecting the positions dtype at runtime.
Sourcepub fn positions_ref(&self) -> PositionsRef<'_>
pub fn positions_ref(&self) -> PositionsRef<'_>
Get a reference to the positions, dispatched by dtype.
Sourcepub fn nb_streamlines(&self) -> usize
pub fn nb_streamlines(&self) -> usize
Number of streamlines.
Sourcepub fn nb_vertices(&self) -> usize
pub fn nb_vertices(&self) -> usize
Number of vertices.
Sourcepub fn with_typed<R>(
&self,
on_f16: impl FnOnce(&TrxFile<f16>) -> R,
on_f32: impl FnOnce(&TrxFile<f32>) -> R,
on_f64: impl FnOnce(&TrxFile<f64>) -> R,
) -> R
pub fn with_typed<R>( &self, on_f16: impl FnOnce(&TrxFile<f16>) -> R, on_f32: impl FnOnce(&TrxFile<f32>) -> R, on_f64: impl FnOnce(&TrxFile<f64>) -> R, ) -> R
Dispatch to a closure with a concrete &TrxFile<P>.
pub fn positions_f32(&self) -> Vec<[f32; 3]>
pub fn offsets_vec(&self) -> Vec<u32>
pub fn dpv_entries(&self) -> Vec<(String, DataArrayInfo)>
pub fn dps_entries(&self) -> Vec<(String, DataArrayInfo)>
pub fn groups_owned(&self) -> Vec<(String, Vec<u32>)>
pub fn dpg_group_entries(&self) -> Vec<(String, Vec<(String, DataArrayInfo)>)>
pub fn scalar_dpv_f32(&self, name: &str) -> Result<Vec<f32>>
pub fn scalar_dps_f32(&self, name: &str) -> Result<Vec<f32>>
Sourcepub fn with_updated_header(self, header: Header) -> Self
pub fn with_updated_header(self, header: Header) -> Self
Return a new AnyTrxFile with the header replaced.
pub fn save(&self, path: &Path) -> Result<()>
pub fn convert_positions_dtype(&self, dtype: DType) -> Result<Self>